﻿#~*~ coding: utf-8 ~*~

"""
@ Aufruf: python porterStemmer_kommz_hu_ME.py

Ein Porter-Stemmer für das Ungarische nach dem light1-Stemmer von Anna Tordai.

Dieser Stemmingalgorithmus entfernt Flexionsendungen von Nomen.
Nomen sind im Ungarischen flektiert nach
- Kasus
- Numerus
- Person
- Besitz

@ Author: Eva Mujdricza
@ Quellen:
	http://snowball.tartarus.org/algorithms/hungarian/stemmer.html
	http://snowball.tartarus.org/algorithms/hungarian/stem_ISO_8859_1.sbl
	http://www.unine.ch/info/clef/hungarianStemmer.txt
	http://snowball.tartarus.org/otherlangs/german_py.txt
	www.cs.vu.nl/~atordai/Scriptie.pdf

@ Änderungen:
#ME#Konsonanten ergänzt durch "hh, ddz"
#ME#DoppelKonsonanten sortiert
"""

import string


def stem(wort, stopp = False):
	vokale = ['a', '\xa0', 'e', '\x82', 'i', '\xa1', 'o', '\xa2', '\x94', '\xe4', 'u', '\xe9', '\x81', '\x96'] #['a', 'á', 'e', 'é', 'i', 'í', 'o', 'ó', 'ö', 'õ', 'u', 'ú', 'ü', 'û']
	konsonanten = ['b', 'c', 'd', 'f', 'g', 'h', 'j', 'k', 'l', 'm', 'n', 'p', 'q', 'r', 's', 't', 'v', 'w', 'x', 'y', 'z']
	konsD = ['bb', 'ff', 'hh', 'jj', 'kk', 'mm', 'pp', 'rr', 'vv', 'gg', 'll', 'nn', 'tt', 'cc', 'zz', 'dd', 'ss']
	konsV2 = ['cs', 'dz', 'dzs', 'gy', 'ly', 'ny', 'sz', 'ty', 'zs']
	konsV3 = ['ggy', 'lly', 'nny', 'tty', 'ccs', 'zzs', 'ddz', 'ssz']
	konsV4 = ["ddzs"]

	print "\n>>> VORBEREITUNG: "
	
	#   R1 siehe http://snowball.tartarus.org/algorithms/hungarian/stemmer.html
	r1 =''
	p1 = 0
	
	#   Die Stoppliste; Wörter in dieser Liste werden nicht 'gestemmt', wenn stop  = 'True' an die Funktion übergeben wurde -- bisher ist die Stoppliste leer
	stoppliste =[]
	if ((stopp == True) and (wort in stoppliste)):
		print "\nDas Wort ist in der Stoppwortliste!"
		return wort
	else:
		pass
	
	#   Wortstämme werden klein geschrieben
	# Bemerkung: es lohnt sich sowieso nur Wörter in Kleinbuchstaben einzugeben
	wort = wort.lower()
	print "\nDas Wort wird in Kleinschreibung \x81berf\x81hrt: \n-> ", wort
	
	#   Wenn 'stop'p und Wort in stoppliste gib 'wort' zurück 
	if ((stopp == True) and (wort in stoppliste)):
		return wort
	
	#   r1, p1 werden mit Werten belegt
	try:
		gueltig = False
		if (wort[0] in vokale): #- Beginnt das Wort mit V -> r1 = Wortteil hinter dem ersten K
			for i in range(len(wort[1:])):
				if wort[i] in konsonanten:
				#TODO# die KB und KD beachten
					p1 = i+1
					r1 = wort[p1:]
					gueltig = True
					break
				else: gueltig = False
		elif (wort[0] in konsonanten): #- Beginnt das Wort mit K -> r1 = Wortteil hinter dem ersten V
			for i in range(len(wort[1:])):
				if wort[i] in vokale:
					p1 = i+1
					r1 = wort[p1:]
					gueltig = True
					break
				else: gueltig = False
		elif (gueltig == False): #- Enthält das Wort nur V oder nur K -> r1 = leeres Wort
			print "\n>>> BEARBEITUNG: "
			print "(Keine Bearbeitung m\x94glich.)"
			return wort
		else: pass
		print "wort: ", wort
		print "r1: ", r1
	except: 
		print "\n!!!\nAusnahmefall bei der Initialisierung der Position für r1.\n!!!\n"
	
#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#
	
	print "\n>>> BEARBEITUNG: "
	bb = 0 # Zähler überprüft, ob etwas in der Bearbeitungsphase passiert
	#   Die Schritte 1 bis 9 'stemmen' das übergebene Wort. 
	
#-----------------------------------------------------------------------------
	
	#   Schritt 1: Entfernung von Instrumental C|Cal, C|Cel (val, vel)
	suff_1 = ['al', 'el']
	try:
		for e in suff_1:
			if e == (r1[-(len(e)):]): # suff_1 im r1
				if (wort[-(len(e)+1):-(len(e))] == wort[-(len(e)+2):-(len(e)+1)]): # hat wort CC vor suff_1?
					wort = wort[:-(len(e)+1)]
					r1 = r1[:-(len(e)+1)]
					bb = 1
					print "\nSchritt 1a: 'Cal' / 'Cel' werden entfernt.\n-> ", wort
					break
				elif (wort[-(len(e)+3):-(len(e))] in konsV3): # z.B. könnyel
					wort = wort[:-(len(e)+2)] + wort[-(len(e)+1):-(len(e))]
					r1 = r1[:-(len(e)+2)] + r1[-(len(e)+1):-(len(e))]
					bb = 1
					print "\nSchritt 1b: C + 'al' / 'el' werden von Wortformen mit konsV3 entfernt.\n-> ", wort
			else: # sonst
				pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 1.\n!!!\n"
		return wort
	#TEST#print "Wort nach Schritt 1: ", wort
	#TEST#print "r1 nach Schritt 1: ", r1

#-----------------------------------------------------------------------------
	
	# Schritt 2: Entfernung von Endungen: ban   ben   ba   be   ra   re   nak   nek   val   vel   tól   tõl   ról   rõl   ból   bõl   hoz   hez   höz   nál   nél   ig   at   et   ot   öt   ért   képp   képpen   kor   ul   ül   vá   vé   onként   enként   anként   ként   en   on   an   ön   n   t
	
	# Suff_2 original
	# Suff_2_L6 = ['képpen']
	# Suff_2_L5 = ['onként', 'enként', 'anként']
	# Suff_2_L4 = ['képp', 'ként']
	# Suff_2_L3 = ['ban', 'ben', 'nak', 'nek', 'val', 'vel', 'tól', 'tõl', 'ról', 'rõl', 'ból', 'bõl', 'hoz', 'hez', 'höz', 'nál', 'nél', 'ért', 'kor'] 
	# Suff_2_L2 = ['ba', 'be', 'ra', 're', 'ig', 'at', 'et', 'ot', 'öt', 'ul', 'ül', 'vá', 'vé', 'en', 'on', 'an', 'ön']
	# Suff_2_L1 = ['n', 't']
	
	# Suff_2 mit hexadez. ersetzt
	suff_2_L6 = ['k\x82ppen']
	suff_2_L5 = ['onk\x82nt', 'enk\x82nt', 'ank\x82nt']
	suff_2_L4 = ['k\x82pp', 'k\x82nt']
	suff_2_L3 = ['ban', 'ben', 'nak', 'nek', 'val', 'vel', 't\xa2l', 't\xe4l', 'r\xa2l', 'r\xe4l', 'b\xa2l', 'b\xe4l', 'hoz', 'hez', 'h\x94z', 'n\xa0l', 'n\x82l', '\x82rt', 'kor'] 
	suff_2_L2 = ['ba', 'be', 'ra', 're', 'ig', 'at', 'et', 'ot', '\x94t', 'ul', '\x81l', 'v\xa0', 'v\x82', 'en', 'on', 'an', '\x94n']
	suff_2_L1 = ['n', 't']
	
	schritt2_aktiv = False
	try:
		if len(r1) > 5:
			for e in suff_2_L6:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L6: 'k\x82ppen' wird entfernt.\n-> ", wort
					break
				else: pass
		if len(r1) > 4:
			for e in suff_2_L5:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L5: 'onk\x82nt' / 'enk\x82nt'/ 'ank\x82nt' werden entfernt.\n-> ", wort
					break
				else: pass
		if len(r1) > 3:
			for e in suff_2_L4:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L4: 'k\x82pp' / 'k\x82nt' werden entfernt.\n-> ", wort
					break
				else: pass
		if len(r1) > 2:
			for e in suff_2_L3:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L3: 'ban' / 'ben' / 'nak' / 'nek' / 'val' / 'vel' / 't\xa2l' / 't\xe4l' / 'r\xa2l' / 'r\xe4l' / 'b\xa2l' / 'b\xe4l' / 'hoz' / 'hez' / 'h\x94z' / 'n\xa0l' / 'n\x82l' / '\x82rt' / 'kor' werden entfernt.\n-> ", wort
					break
				else: pass
		if len(r1) > 1:
			for e in suff_2_L2:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L2: 'ba' / 'be' / 'ra' / 're' / 'ig' / 'at' / 'et' / 'ot' / '\x94t' / 'ul' / '\x81l' / 'v\xa0' / 'v\x82' / 'en' / 'on' / 'an' / '\x94n' werden entfernt.\n-> ", wort
					break
				else: pass
		if len(r1) > 0:
			for e in suff_2_L1:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					schritt2_aktiv = True
					print "\nSchritt 2_L1: 'n' / 't' werden entfernt.\n-> ", wort
					break
				else: pass
		else: 
			pass #???# Wort könnte man schon jetzt zurückgeben, weil keine Endung

		# Schritt 2_aeErsetzung
		if (schritt2_aktiv == True): # wenn etwas im Schritt 2 entfernt wurde
			try:
				if (wort.endswith("\xa0")):
					wort = wort[:-1] + wort[-1].replace("\xa0", "a")
					r1 = r1[:-1] + r1[-1].replace("\xa0", "a")
					bb = 1
					print "Auslaut \"\xa0\" wurde durch \"a\" ersetzt.\n-> ", wort
				elif (wort.endswith("\x82")):
					wort = wort[:-1] + wort[-1].replace("\x82", "e")
					r1 = r1[:-1] + r1[-1].replace("\x82", "e")
					bb = 1
					print "Auslaut \"\x82\" wurde durch \"e\" ersetzt.\n-> ", wort
				else: pass
			except:
				print "\n!!!\nAusnahmefall bei Schritt 2_aeErsetzung.\n!!!\n"
				return wort
		else: pass
		
	except:
		print "\n!!!\nAusnahmefall bei Schritt 2.\n!!!\n"
		return wort
		
	#TEST#print "Wort nach Schritt 2: ", wort
	#TEST#print "r1 nach Schritt 2: ", r1
	
#-----------------------------------------------------------------------------
	
	#Schritt 3: Ersetzung von 'ánként', 'án', durch 'a', bzw. 'én' durch 'e'
	
	suff_3_a = ['\xa0nként', '\xa0n'] #['ánként', 'án']
	suff_3_e = ['\x82n'] #['én']
	
	try:
		for e in suff_3_a:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 3_a: '\xa0nk\x82nt' / '\xa0n' werden durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_3_e:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 3_e: '\x82n' wird durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 3.\n!!!\n"
		return wort
		
	#TEST#print "Wort nach Schritt 3: ", wort
	#TEST#print "r1 nach Schritt 3: ", r1
	
#-----------------------------------------------------------------------------
	
	# Schritt 4: Entfernung von 'astul', 'estül', 'stul', 'stül', sowie Ersetzung von 'ástul' durch 'a', bzw. von 'élstül' durch 'e'
	
	suff_4_stul_ohneDK = ['astul', 'est\x81l', 'stul', 'st\x81l']
	suff_4_astul_mitDK = ['\xa0stul']
	suff_4_estul_mitDK = ['\x82st\x81l']
	
	try:
		for e in suff_4_stul_ohneDK:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))]
				r1 = r1[:-(len(e))]
				bb = 1
				print "\nSchritt 4_ohneDK: 'astul' / 'est\x81l' / 'stul' / 'st\x81l' werden entfernt.\n-> ", wort
				break
			else: pass
		for e in suff_4_astul_mitDK:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 4_a_mitDK: '\xa0stul' wird durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_4_estul_mitDK:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 4_e_mitDK: '\x82st\x81l' wird durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 4.\n!!!\n"
		return wort
	#TEST#print "Wort nach Schritt 4: ", wort
	#TEST#print "r1 nach Schritt 4: ", r1
	
#-----------------------------------------------------------------------------
	
	#Schritt 5: Factiv: Entfernung von 'á', 'é' nach Doppelkonsonant 
	
	suff_5 = ['\xa0', '\x82']
	
	try:
		for e in suff_5:
			if e == (r1[-(len(e)):]): # suff_5 im r1
				if (wort[-(len(e)+1):-(len(e))] == wort[-(len(e)+2):-(len(e)+1)]): # hat wort CC vor suff_5?
					wort = wort[:-(len(e)+1)]
					r1 = r1[:-(len(e)+1)]
					bb = 1
					print "\nSchritt 5: 'C\xa0' / 'C\x82' werden entfernt.\n-> ", wort
					break
			else: # sonst
				pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 5.\n!!!\n"
		return wort
	#TEST#print "Wort nach Schritt 5: ", wort
	#TEST#print "r1 nach Schritt 5: ", r1
	
#-----------------------------------------------------------------------------
	
	#Schritt 6: Besitz: in absteigender Endungslänge: Ersetzung von 'áké', 'áéi' durch 'a', bzw. von 'éké', 'ééi', 'éé' durch 'e', 0der Entfernung von 'oké', 'öké', 'aké', 'eké', 'ké', 'éi', 'é'
	
	suff_6_Entf = ['ok\x82', '\x94k\x82', 'ak\x82', 'ek\x82', 'k\x82', '\x82i', '\x82'] #['oké', 'öké', 'aké', 'eké', 'ké', 'éi', 'é']
	suff_6_aErs = ['\xa0k\x82', '\xa0\x82i'] #['áké', 'áéi']
	suff_6_eErs = ['\x82k\x82', '\x82\x82i', '\x82\x82'] #['éké', 'ééi', 'éé']
	
	try:
		for e in suff_6_aErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 6_aErs: '\xa0k\x82' / '\xa0\x82i' werden durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_6_eErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 6_eErs: '\x82k\x82' / '\x82\x82i' / '\x82\x82' werden durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_6_Entf:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))]
				r1 = r1[:-(len(e))]
				bb = 1
				print "\nSchritt 6_Entf: 'ok\x82' / '\x94k\x82' / 'ak\x82' / 'ek\x82' / 'k\x82' / '\x82i' / '\x82' werden entfernt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 6.\n!!!\n"
		return wort
		
	#TEST#print "Wort nach Schritt 6: ", wort
	#TEST#print "r1 nach Schritt 6: ", r1
#-----------------------------------------------------------------------------
	
	#Schritt 7: Besitz in Singular: in absteigender Endungslänge: Ersetzung von 'ánk', 'ájuk', 'ám', 'ád', 'á' durch 'a', bzw. Ersetzung von 'énk', 'éjük', 'ém', 'éd', 'é' durch 'e'; oder Entfernung von 'ünk', 'unk', 'nk', 'juk', 'jük', 'uk', 'ük', 'em', 'om', 'am', 'm', 'od', 'ed', 'ad', 'öd', 'd', 'ja', 'je', 'a'. 'e', 'o'
	
	suff_7_Entf = ['\x81nk', 'unk', 'nk', 'juk', 'j\x81k', 'uk', '\x81k', 'em', 'om', 'am', 'm', 'od', 'ed', 'ad', '\x94d', 'd', 'ja', 'je', 'a', 'e', 'o'] #['ünk', 'unk', 'nk', 'juk', 'jük', 'uk', 'ük', 'em', 'om', 'am', 'm', 'od', 'ed', 'ad', 'öd', 'd', 'ja', 'je', 'a', 'e', 'o']
	suff_7_aErs = ['\xa0nk', '\xa0juk', '\xa0m', '\xa0d', '\xa0'] #['ánk', 'ájuk', 'ám', 'ád', 'á']
	suff_7_eErs = ['\x82nk', '\x82jük', '\x82m', '\x82d', '\x82'] #['énk', 'éjük', 'ém', 'éd', 'é']
	
	try:
		for e in suff_7_aErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 7_aErs: '\xa0nk' / '\xa0juk' / '\xa0m' / '\xa0d' / '\xa0' werden durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_7_eErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 7_eErs: '\x82nk' / '\x82jük' / '\x82m' / '\x82d' / '\x82' werden durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_7_Entf:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))]
				r1 = r1[:-(len(e))]
				bb = 1
				print "\nSchritt 7_Entf: '\x81nk' / 'unk' / 'nk' / 'juk' / 'j\x81k' / 'uk' / '\x81k' / 'em' / 'om' / 'am' / 'm' / 'od' / 'ed' / 'ad' / '\x94d' / 'd' / 'ja' / 'je' / 'a' / 'e' / 'o' werden entfernt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 7.\n!!!\n"
		return wort
		
	#TEST#print "Wort nach Schritt 7: ", wort
	#TEST#print "r1 nach Schritt 7: ", r1
	
#-----------------------------------------------------------------------------
	
	#Schritt 8: Besitz in Plural: in absteigender Endungslänge: Ersetzung von 'áim', 'áid', 'ái', 'áink', 'áitok', 'áik', durch 'a', bzw. Ersetzung von 'éim', 'éid', 'éi', 'éink', 'éitek', 'éik' durch 'e'; oder Entfernung von 'jaim', 'jeim', 'aim', 'eim', 'im', 'jaid', 'jeid', 'aid', 'eid', 'id', 'jai', 'jei', 'ai', 'ei', 'i', 'jaink', 'jeink', 'eink', 'aink', 'ink', 'jaitok', 'jeitek', 'aitok', 'eitek', 'itek', 'jeik', 'jaik', 'aik', 'eik', 'ik'
	
	suff_8_Entf = ['jaim', 'jeim', 'aim', 'eim', 'im', 'jaid', 'jeid', 'aid', 'eid', 'id', 'jai', 'jei', 'ai', 'ei', 'i', 'jaink', 'jeink', 'eink', 'aink', 'ink', 'jaitok', 'jeitek', 'aitok', 'eitek', 'itek', 'jeik', 'jaik', 'aik', 'eik', 'ik'] #['jaim', 'jeim', 'aim', 'eim', 'im', 'jaid', 'jeid', 'aid', 'eid', 'id', 'jai', 'jei', 'ai', 'ei', 'i', 'jaink', 'jeink', 'eink', 'aink', 'ink', 'jaitok', 'jeitek', 'aitok', 'eitek', 'itek', 'jeik', 'jaik', 'aik', 'eik', 'ik']
	suff_8_aErs = ['\xa0im', '\xa0id', '\xa0i', '\xa0ink', '\xa0itok', '\xa0ik'] #['áim', 'áid', 'ái', 'áink', 'áitok', 'áik']
	suff_8_eErs = ['\x82im', '\x82id', '\x82i', '\x82ink', '\x82itek', '\x82ik'] #['éim', 'éid', 'éi', 'éink', 'éitek', 'éik']
	
	try:
		for e in suff_8_aErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 8_aErs: '\xa0im' / '\xa0id' / '\xa0i' / '\xa0ink' / '\xa0itok' / '\xa0ik' werden durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_8_eErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 8_eErs: '\x82im' / '\x82id' / '\x82i' / '\x82ink' / '\x82itek' / '\x82ik' werden durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_8_Entf:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))]
				r1 = r1[:-(len(e))]
				bb = 1
				print "\nSchritt 8_Entf: 'jaim' / 'jeim' / 'aim' / 'eim' / 'im' / 'jaid' / 'jeid' / 'aid' / 'eid' / 'id' / 'jai' / 'jei' / 'ai' / 'ei' / 'i' / 'jaink' / 'jeink' / 'eink' / 'aink' / 'ink' / 'jaitok' / 'jeitek' / 'aitok' / 'eitek' / 'itek' / 'jeik' / 'jaik' / 'aik' / 'eik' / 'ik' werden entfernt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 8.\n!!!\n"
		return wort
		
	#TEST#print "Wort nach Schritt 8: ", wort
	#TEST#print "r1 nach Schritt 8: ", r1
	
#-----------------------------------------------------------------------------
	
	#Schritt 9: Plural: in absteigender Endungslänge: Ersetzung von 'ák' durch 'a', bzw. von 'ék' durch 'e', oder Entfernung von 'ök', 'ok', 'ek', 'ak', 'k'
	
	suff_9_Entf = ['\x94k', 'ok', 'ek', 'ak', 'k'] #['ök', 'ok', 'ek', 'ak', 'k']
	suff_9_aErs = ['\xa0k'] #['ák']
	suff_9_eErs = ['\x82k'] #['ék']
	
	try:
		for e in suff_9_aErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "a"
				r1 = r1[:-(len(e))] + "a"
				bb = 1
				print "\nSchritt 9_aErs: '\xa0k' wird durch \"a\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_9_eErs:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))] + "e"
				r1 = r1[:-(len(e))] + "e"
				bb = 1
				print "\nSchritt 9_eErs: '\x82k' wird durch \"e\" ersetzt.\n-> ", wort
				break
			else: pass
		for e in suff_9_Entf:
			if e in r1[-(len(e)):]:
				wort = wort[:-(len(e))]
				r1 = r1[:-(len(e))]
				bb = 1
				print "\nSchritt 9_Entf: '\x94k' / 'ok' / 'ek' / 'ak' / 'k' werden entfernt.\n-> ", wort
				break
			else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 9.\n!!!\n"
	if bb == 0:
		print "(Keine Bearbeitung m\x94glich.)"
		
		
	#TEST#print "Wort nach Schritt 9: ", wort
	#TEST#print "r1 nach Schritt 9: ", r1
	
#-----------------------------------------------------------------------------
	#Schritt 10a: Entfernung von Komparativendungen:  'obb', 'abb', 'ebb'; 'bb'
	
	suff_10a_Vbb = ['obb', 'abb', 'ebb']
	suff_10a_bb = ['bb']
	bb_10a = 0 # merkt, ob im Schritt 10a etwas entfernt wird
	
	try:
		if wort[-5:] == "szebb": #szép > szebb
			wort = wort[:-3] + '\x82p'
			if len(r1) > 2:
				r1 = r1[:-3] + '\x82p'
			elif len(r1) == 2:
				r1 = 'p'
			else:
				r1 = ""
			bb = 1
			bb_10a = 1
		else:
			for e in suff_10a_Vbb:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					bb_10a = 1
					print "\nSchritt 10a_Vbb: 'obb' / 'abb' / 'ebb' werden entfernt.\n-> ", wort
					break
				else: pass
			for e in suff_10a_bb:
				if e in r1[-(len(e)):]:
					wort = wort[:-(len(e))]
					r1 = r1[:-(len(e))]
					bb = 1
					bb_10a = 1
					print "\nSchritt 10a_bb: 'bb' wird entfernt.\n-> ", wort
					break
				else: pass
	except:
		print "\n!!!\nAusnahmefall bei Schritt 10a.\n!!!\n"

#-----------------------------------------------------------------------------
	#Schritt 10b: Entfernung von Superlativpräfixe: 'legesleg', 'leg'
	
	if (bb_10a == 1):
		try:
			if wort[:8] == "legesleg":
				wort = wort[8:]
				r1 = r1[8:]
				bb = 1
				print "\nSchritt 10b: 'legesleg' (Pr\x84fix) wird entfernt.\n-> ", wort
			elif wort[:3] == "leg":
				wort = wort[3:]
				r1 = r1[3:]
				bb = 1
				print "\nSchritt 10a_bb: 'leg' (Pr\x84fix) wird entfernt.\n-> ", wort
		except:
			print "\n!!!\nAusnahmefall bei Schritt 10b.\n!!!\n"
	else:
		pass
	

#-----------------------------------------------------------------------------
	
	print "\n>>> AUSGABE:\n=> Der Stamm des Wortes = ", wort
	return wort
	
#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#
	
def wortformEinlesen():
	print ">>> EINGABE: "
	x = raw_input()
	return x
	
#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#
	
def regelZeigen_hu():
	f = open("Regeln_hu.txt")
	for i in f.readlines():
		print i
	f.close()
	
#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~##~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#~#
	
	
if __name__ == "__main__":
	print "\n\t* * * Das ist ein Porter-Stemmer f\x81r das Ungarische. * * *\n"
	antwort = "j"
	while (antwort == "j"):
		print "\n", 78*"~", "\n"  
		eingabe = wortformEinlesen()
		stem(eingabe)
		print "\n", 39*"~ "
		print "\n>>> Weitere Stammermittlungen? (j/n/r)\n\tj=ja, n=nein, r=Regeln zeigen"
		antwort = raw_input()
		if antwort == "r":
			print "\n"
			regelZeigen_hu()
			print "\n", 78*"~"
			print "\n>>> Weitere Stammermittlungen? (j/n)\n\tj=ja, n=nein"
			antwort = raw_input()
